@@ -25,6 +25,15 @@ ROS
 
     RosClient
 
+Tasks
+-----
+
+.. autosummary::
+    :toctree: generated/
+    :nosignatures:
+
+    CancellableTask
+
 Exceptions
 ----------
 
@@ -39,11 +48,13 @@ Exceptions
 """
 
 from .exceptions import *
+from .tasks import *
 from .ros.client import *
 from .vrep.client import *
 
 from .exceptions import __all__ as a
-from .ros.client import __all__ as b
-from .vrep.client import __all__ as c
+from .tasks import __all__ as b
+from .ros.client import __all__ as c
+from .vrep.client import __all__ as d
 
-__all__ = a + b + c
+__all__ = a + b + c + d
