@@ -17,5 +17,7 @@ Package with functionality to interact with the `ROS platform <http://ros.org/>`
 
 from __future__ import absolute_import
 
-from .messages import *
+from .client import RosClient
+from .client import RosError
 from .direct_ur_action_client import DirectUrActionClient
+from .messages import *
